@@ -24,8 +24,19 @@
                             Include header files
 ******************************************************************************/
 
+#define _XOPEN_SOURCE	500
+
 #include "jobrep_odbc_api.h"
 
+#include <string.h>
+#include <stdlib.h>
+#include <sql.h>
+#include <sqlext.h>
+#include <sqltypes.h>
+
+#include <lcmaps/lcmaps_log.h>
+
+
 
 /******************************************************************************
                                 Definitions
@@ -36,7 +47,7 @@
 ******************************************************************************/
 
 static int
-ODBC_Errors (struct jr_db_handle_s *, short, char *);
+ODBC_Errors (struct jr_db_handle_s *, short, const char *);
 
 /******************************************************************************
                        Define module specific variables
@@ -64,7 +75,7 @@ SQL_IgnoreErrors_Reset(struct jr_db_handle_s *db_handle) {
 
 
 static int
-ODBC_Errors (struct jr_db_handle_s *db_handle, short last_error, char *where) {
+ODBC_Errors (struct jr_db_handle_s *db_handle, short last_error, const char *where) {
     unsigned char  buf[250];
     unsigned char  sqlstate[15];
     unsigned char *search;
@@ -86,7 +97,7 @@ ODBC_Errors (struct jr_db_handle_s *db_handle, short last_error, char *where) {
     /* Get statement errors */
     if (db_handle->jobrep_henv && db_handle->jobrep_hdbc && db_handle->jobrep_hstmt) {
         while (SQLError (db_handle->jobrep_henv, db_handle->jobrep_hdbc, db_handle->jobrep_hstmt,
-                         sqlstate, NULL, buf, sizeof(buf), NULL) == SQL_SUCCESS) {
+                         sqlstate, NULL, buf, (SQLSMALLINT)sizeof(buf), NULL) == SQL_SUCCESS) {
             search = buf;
             for (i = 0; i < sizeof(buf); i++) {
                 if (strncmp((char *)search, "Duplicate", strlen("Duplicate")) == 0) {
@@ -103,7 +114,7 @@ ODBC_Errors (struct jr_db_handle_s *db_handle, short last_error, char *where) {
     /* Get connection errors */
     if (db_handle->jobrep_henv && db_handle->jobrep_hdbc) {
         while (SQLError (db_handle->jobrep_henv, db_handle->jobrep_hdbc, SQL_NULL_HSTMT,
-                         sqlstate, NULL, buf, sizeof(buf), NULL) == SQL_SUCCESS) {
+                         sqlstate, NULL, buf, (SQLSMALLINT)sizeof(buf), NULL) == SQL_SUCCESS) {
             lcmaps_log(LOG_ERR, "[Connection Error @ %s : %s]%s, SQLSTATE=%s\n",
                                 where, SQL_ERROR_CODE_STRING(last_error), buf, sqlstate);
         }
@@ -112,7 +123,7 @@ ODBC_Errors (struct jr_db_handle_s *db_handle, short last_error, char *where) {
     /* Get environmental errors */
     if (db_handle->jobrep_henv) {
         while (SQLError (db_handle->jobrep_henv, SQL_NULL_HDBC, SQL_NULL_HSTMT,
-                         sqlstate, NULL, buf, sizeof(buf), NULL) == SQL_SUCCESS) {
+                         sqlstate, NULL, buf, (SQLSMALLINT)sizeof(buf), NULL) == SQL_SUCCESS) {
             lcmaps_log(LOG_ERR, "[Environmental Error @ %s : %s]%s, SQLSTATE=%s\n",
                                 where, SQL_ERROR_CODE_STRING(last_error), buf, sqlstate);
         }
@@ -151,8 +162,8 @@ ODBC_Connect (char *dsn, char *username, char *password) {
     /* Allocate */
     jr_db_handle = malloc(sizeof(struct jr_db_handle_s));
     if (jr_db_handle == NULL) {
-        lcmaps_log(LOG_ERR, "%s: Could not allocate %u bytes for the DB handle.\n",
-                            __func__, sizeof(struct jr_db_handle_s));
+        lcmaps_log(LOG_ERR, "%s: Could not allocate %lu bytes for the DB handle.\n",
+                            __func__, (long unsigned)sizeof(struct jr_db_handle_s));
         goto failure;
     }
     /* Cleanup */
@@ -185,8 +196,8 @@ ODBC_Connect (char *dsn, char *username, char *password) {
                           (SQLCHAR*) password, SQL_NTS);
     if ((V_OD_erg != SQL_SUCCESS) && (V_OD_erg != SQL_SUCCESS_WITH_INFO)) {
             lcmaps_log(LOG_ERR, "%s: Error SQLConnect\n", __func__);
-            SQLGetDiagRec(SQL_HANDLE_DBC, jr_db_handle->jobrep_hdbc, 1,
-                          V_OD_stat, &V_OD_err, V_OD_msg, sizeof(V_OD_msg), &V_OD_mlen);
+            SQLGetDiagRec(SQL_HANDLE_DBC, jr_db_handle->jobrep_hdbc, (SQLSMALLINT)1,
+                          V_OD_stat, &V_OD_err, V_OD_msg, (SQLSMALLINT)sizeof(V_OD_msg), &V_OD_mlen);
             ODBC_Errors(jr_db_handle, V_OD_erg, (char *)V_OD_msg);
             if (jr_db_handle->jobrep_henv) {
                 SQLFreeHandle(SQL_HANDLE_ENV, jr_db_handle->jobrep_henv);
@@ -200,8 +211,8 @@ ODBC_Connect (char *dsn, char *username, char *password) {
     if (status != SQL_SUCCESS && status != SQL_SUCCESS_WITH_INFO)
         return -4;
 
-    // Turn AUTOCOMMIT off so SQL statements can be grouped into a
-    // transaction
+    /* Turn AUTOCOMMIT off so SQL statements can be grouped into a */
+    /* transaction */
     status = SQLSetConnectOption(jobrep_hdbc, SQL_AUTOCOMMIT, SQL_AUTOCOMMIT_OFF);
     if (status != SQL_SUCCESS)
     {
@@ -209,10 +220,10 @@ ODBC_Connect (char *dsn, char *username, char *password) {
         return -5;
     }
 
-    //SQLSetConnectOption (hdbc, SQL_TXN_ISOLATION_OPTION, SQL_TRANSACTION_SERIALIZABLE);
-    //SQLSetConnectOption (hdbc, SQL_TXN_ISOLATION_OPTION, SQL_TRANSACTION_REPEATABLE_READ);
+    /*SQLSetConnectOption (hdbc, SQL_TXN_ISOLATION_OPTION, SQL_TRANSACTION_SERIALIZABLE); */
+    /*SQLSetConnectOption (hdbc, SQL_TXN_ISOLATION_OPTION, SQL_TRANSACTION_REPEATABLE_READ); */
     SQLSetConnectOption (jobrep_hdbc, SQL_TXN_ISOLATION_OPTION, SQL_TRANSACTION_READ_UNCOMMITTED);
-    //SQLSetConnectOption (hdbc, SQL_TXN_ISOLATION_OPTION, SQL_TXN_READ_COMMITTED);
+    /*SQLSetConnectOption (hdbc, SQL_TXN_ISOLATION_OPTION, SQL_TXN_READ_COMMITTED); */
 
     SQLSetConnectOption (jobrep_hdbc, SQL_OPT_TRACEFILE, (UDWORD) "\\SQL.LOG");
     jobrep_connected = 1;
@@ -249,7 +260,7 @@ ODBC_Disconnect(struct jr_db_handle_s *db_handle) {
         SQLFreeHandle(SQL_HANDLE_ENV, db_handle->jobrep_henv);
 
     free(db_handle);
-    db_handle = NULL;
+/*    db_handle = NULL;*/ /* No point, we're returning... */
 
     return 0;
 }
@@ -287,13 +298,13 @@ SQL_BeginTransaction(struct jr_db_handle_s *db_handle) {
     if (status != SQL_SUCCESS && status != SQL_SUCCESS_WITH_INFO)
         return -4;
 
-    // Turn AUTOCOMMIT off so SQL statements can be grouped into a
-    // transaction
+    /* Turn AUTOCOMMIT off so SQL statements can be grouped into a */
+    /* transaction */
 
-    //SQLSetConnectOption (hdbc, SQL_TXN_ISOLATION_OPTION, SQL_TRANSACTION_SERIALIZABLE);
-    //SQLSetConnectOption (hdbc, SQL_TXN_ISOLATION_OPTION, SQL_TRANSACTION_REPEATABLE_READ);
+    /*SQLSetConnectOption (hdbc, SQL_TXN_ISOLATION_OPTION, SQL_TRANSACTION_SERIALIZABLE); */
+    /*SQLSetConnectOption (hdbc, SQL_TXN_ISOLATION_OPTION, SQL_TRANSACTION_REPEATABLE_READ); */
     SQLSetConnectOption (jobrep_hdbc, SQL_TXN_ISOLATION_OPTION, SQL_TRANSACTION_READ_UNCOMMITTED);
-    //SQLSetConnectOption (hdbc, SQL_TXN_ISOLATION_OPTION, SQL_TXN_READ_COMMITTED);
+    /*SQLSetConnectOption (hdbc, SQL_TXN_ISOLATION_OPTION, SQL_TXN_READ_COMMITTED); */
 
     SQLSetConnectOption (jobrep_hdbc, SQL_OPT_TRACEFILE, (UDWORD) "\\SQL.LOG");
     jobrep_connected = 1;
@@ -369,7 +380,7 @@ SQL_BindParam(struct jr_db_handle_s *db_handle,
           c_type,
           sql_type,
           0,
-          0,
+          (SQLSMALLINT)0,
           data,
           0,
           NULL);
@@ -548,8 +559,8 @@ SQL_Query(struct jr_db_handle_s *db_handle) {
 
     db_handle->resultset->columns = malloc(sizeof(TColumn) * colCnt);
     if (db_handle->resultset->columns == NULL) {
-        lcmaps_log(LOG_ERR, "%s: Error in allocating %u bytes\n",
-                            __func__, sizeof(TColumn) * colCnt);
+        lcmaps_log(LOG_ERR, "%s: Error in allocating %lu bytes\n",
+                            __func__, (long unsigned)sizeof(TColumn) * colCnt);
 	res = SQL_ERROR;
         goto sql_query_cleanup;
     }
@@ -558,8 +569,8 @@ SQL_Query(struct jr_db_handle_s *db_handle) {
 
     db_handle->resultset->data = malloc(sizeof(TRow) * rowCnt);
     if (db_handle->resultset->data == NULL) {
-        lcmaps_log(LOG_ERR, "%s: Error in allocating %u bytes\n",
-                            __func__, sizeof(TRow) * rowCnt);
+        lcmaps_log(LOG_ERR, "%s: Error in allocating %lu bytes\n",
+                            __func__, (long unsigned)sizeof(TRow) * rowCnt);
 	res = SQL_ERROR;
         goto sql_query_cleanup;
     }
@@ -568,8 +579,8 @@ SQL_Query(struct jr_db_handle_s *db_handle) {
     for (i = 0; i < rowCnt; i++) {
         db_handle->resultset->data[i] = malloc(sizeof(TField) * colCnt);
         if (db_handle->resultset->data[i] == NULL) {
-            lcmaps_log(LOG_ERR, "%s: Error in allocating %u bytes\n",
-                                __func__, sizeof(TField) * colCnt);
+            lcmaps_log(LOG_ERR, "%s: Error in allocating %lu bytes\n",
+                                __func__, (long unsigned)sizeof(TField) * colCnt);
 	    res = SQL_ERROR;
             goto sql_query_cleanup;
         }
@@ -589,8 +600,19 @@ SQL_Query(struct jr_db_handle_s *db_handle) {
 
 	/* Read a row, column by column */
 	for (colNum = 0; colNum < colCnt; colNum++) {
+	    void *data;
+	    SQLLEN bufsize_bytes;
+	    void *data_final = NULL;
+
+	    void *data2 = NULL;
+	    void *data3 = NULL;
+	    size_t total_buf = 0;
+	    SQLLEN offset = 0;
+	    int   needs_concat = 0;
+
+
 	    res = SQLDescribeCol(db_handle->jobrep_hstmt, (SQLUSMALLINT)(colNum + 1),
-				(UCHAR *) colName, sizeof (colName),
+				(UCHAR *) colName, (SQLSMALLINT)sizeof(colName),
 				NULL, &colType, &colPrecision,
 				&colScale, &colNullable);
 	    if (res != SQL_SUCCESS) {
@@ -598,8 +620,6 @@ SQL_Query(struct jr_db_handle_s *db_handle) {
 		goto sql_query_cleanup;
 	    }
 
-	    void *data;
-	    SQLLEN bufsize_bytes;
 	    bufsize_bytes = 0;
 	    data = NULL;
 
@@ -656,21 +676,19 @@ SQL_Query(struct jr_db_handle_s *db_handle) {
 	    ********************************/
 	    data = malloc((size_t)bufsize_bytes);
 
-	    void *data_final = NULL;
-
-	    void *data2 = NULL;
-	    void *data3 = NULL;
-	    size_t total_buf = 0;
-	    SQLLEN offset = 0;
-	    int   needs_concat = 0;
-
+	    data2 = NULL;
+	    data3 = NULL;
+	    total_buf = 0;
+	    offset = 0;
+	    needs_concat = 0;
 	    data_final = data;
+
 	    do {
 		/* Fetch data for this field */
 		memset(data, 0, (size_t)bufsize_bytes);
 		res = SQLGetData (db_handle->jobrep_hstmt,
 				  (SQLUSMALLINT)(colNum + 1),
-				  colCType, data, bufsize_bytes,
+				  (SQLSMALLINT)colCType, data, bufsize_bytes,
 				  &colIndicator);
 		if (res == SQL_SUCCESS) {
 		    if (needs_concat) {
@@ -739,19 +757,19 @@ SQL_Query(struct jr_db_handle_s *db_handle) {
 	    db_handle->resultset->data[rowNum][colNum].byte_size = total_buf;
 	    switch(colCType) {
 		case SQL_C_CHAR :
-		    db_handle->resultset->data[rowNum][colNum].v_string = (char *)data_final;
+		    db_handle->resultset->data[rowNum][colNum].v.v_string = (char *)data_final;
 		    break;
 		case SQL_C_LONG :
-		    db_handle->resultset->data[rowNum][colNum].v_long = *((long *)data_final);
+		    db_handle->resultset->data[rowNum][colNum].v.v_long = *((long *)data_final);
 		    break;
 		case SQL_C_SHORT:
-		    db_handle->resultset->data[rowNum][colNum].v_short = *((short *)data_final);
+		    db_handle->resultset->data[rowNum][colNum].v.v_short = *((short *)data_final);
 		    break;
 		case SQL_C_FLOAT:
-		    db_handle->resultset->data[rowNum][colNum].v_float = *((float *)data_final);
+		    db_handle->resultset->data[rowNum][colNum].v.v_float = *((float *)data_final);
 		    break;
 		case SQL_C_DOUBLE:
-		    db_handle->resultset->data[rowNum][colNum].v_double = *((double *)data_final);
+		    db_handle->resultset->data[rowNum][colNum].v.v_double = *((double *)data_final);
 		    break;
 	    }
 	}
@@ -857,7 +875,7 @@ SQL_TResultSet_free(TResultSet *resultset) {
         for (j = 0; j < resultset->colCnt; j++) {
             free(resultset->data[i][j].fieldname);
             if (resultset->data[i][j].type == SQL_C_CHAR) {
-                free(resultset->data[i][j].v_string);
+                free(resultset->data[i][j].v.v_string);
             }
         }
         free(resultset->data[i]);
@@ -869,7 +887,7 @@ SQL_TResultSet_free(TResultSet *resultset) {
     if (resultset->columns) free(resultset->columns);
     resultset->columns = NULL;
     free(resultset);
-    resultset = NULL;
+/*    resultset = NULL;*/ /* No point, we're returning... */
 }
 
 
@@ -923,22 +941,22 @@ SQL_fprintfResultSet (FILE *stream, TResultSet *resultset)
         for (j = 0; j < resultset->colCnt; j++) {
             switch (resultset->data[i][j].type) {
                 case SQL_C_CHAR :
-                    fprintf(stream, "|%25s|", resultset->data[i][j].v_string);
+                    fprintf(stream, "|%25s|", resultset->data[i][j].v.v_string);
                     break;
                 case SQL_C_LONG :
-                    fprintf(stream, "|%25ld|", resultset->data[i][j].v_long);
+                    fprintf(stream, "|%25ld|", resultset->data[i][j].v.v_long);
                     break;
                 case SQL_C_SHORT:
-                    fprintf(stream, "|%25d|", resultset->data[i][j].v_short);
+                    fprintf(stream, "|%25d|", resultset->data[i][j].v.v_short);
                     break;
                 case SQL_C_FLOAT:
-                    fprintf(stream, "|%25f|", resultset->data[i][j].v_float);
+                    fprintf(stream, "|%25f|", resultset->data[i][j].v.v_float);
                     break;
                 case SQL_C_DOUBLE:
-                    fprintf(stream, "|%25f|", resultset->data[i][j].v_double);
+                    fprintf(stream, "|%25f|", resultset->data[i][j].v.v_double);
                     break;
                 default:
-                    fprintf(stream, "|%25ld|", resultset->data[i][j].v_long);
+                    fprintf(stream, "|%25ld|", resultset->data[i][j].v.v_long);
                     break;
             }
         }
