@@ -22,20 +22,9 @@
                             Include header files
 ******************************************************************************/
 
-#include "lcmaps_jobrep_config.h"
 #include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sql.h>
-#include <sqlext.h>
 #include <sqltypes.h>
 
-#include <lcmaps/lcmaps_modules.h>
-#include <lcmaps/lcmaps_arguments.h>
-#include <lcmaps/lcmaps_cred_data.h>
-#include <lcmaps/lcmaps_vo_data.h>
-
-
 /******************************************************************************
                                 Definitions
 ******************************************************************************/
@@ -71,7 +60,7 @@ typedef struct TField_s
         float   v_float;
         double  v_double;
         void   *raw;
-    };
+    } v;
 } TField;
 
 typedef TField * TRow;
