@@ -4,12 +4,25 @@
  * For license conditions see the license file or
  */
 
+#define _XOPEN_SOURCE	600
 
 /*****************************************************************************
                             Include header files
 ******************************************************************************/
 #include "jobrep_data_handling.h"
 
+#include <string.h>
+
+#include <openssl/x509.h>
+#include <openssl/x509v3.h>
+
+#include <sql.h>
+#include <sqlext.h>
+#include <sqltypes.h>
+
+#include <lcmaps/lcmaps_modules.h>
+#include <lcmaps/lcmaps_arguments.h>
+#include <lcmaps/lcmaps_cred_data.h>
 
 /*****************************************************************************/
 
@@ -83,11 +96,11 @@ jobrep_assign_userid(struct jr_db_handle_s *db_handle, STACK_OF(X509) *px509_cha
         goto fail_jobrep;
     }
 
-    if (SQL_BindParam(db_handle, 1, SQL_C_CHAR, SQL_VARCHAR, subject_DN) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_CHAR, SQL_VARCHAR, subject_DN) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the Subject DN value to the query\n", __func__);
         goto fail_jobrep;
     }
-    if (SQL_BindParam(db_handle, 2, SQL_C_CHAR, SQL_VARCHAR, issuer_DN) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_CHAR, SQL_VARCHAR, issuer_DN) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the Issuer DN value to the query\n", __func__);
         goto fail_jobrep;
     }
@@ -112,7 +125,7 @@ jobrep_assign_userid(struct jr_db_handle_s *db_handle, STACK_OF(X509) *px509_cha
     }
 
     /* Store the cert_id */
-    cert_id = db_handle->resultset->data[0][0].v_long;
+    cert_id = db_handle->resultset->data[0][0].v.v_long;
 
     /* Clean up */
     SQL_QueryCloseAndClean(db_handle);
@@ -125,7 +138,7 @@ jobrep_assign_userid(struct jr_db_handle_s *db_handle, STACK_OF(X509) *px509_cha
     }
 
     /* Bind data to Query */
-    if (SQL_BindParam(db_handle, 1, SQL_C_LONG, SQL_INTEGER, &cert_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_LONG, SQL_INTEGER, &cert_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the \"cert_id\" value to the query\n", __func__);
         goto fail_jobrep;
     }
@@ -146,7 +159,7 @@ jobrep_assign_userid(struct jr_db_handle_s *db_handle, STACK_OF(X509) *px509_cha
     }
 
     /* Bind data to Query */
-    if (SQL_BindParam(db_handle, 1, SQL_C_LONG, SQL_INTEGER, &cert_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_LONG, SQL_INTEGER, &cert_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the \"cert_id\" value to the query\n", __func__);
         goto fail_jobrep;
     }
@@ -171,7 +184,7 @@ jobrep_assign_userid(struct jr_db_handle_s *db_handle, STACK_OF(X509) *px509_cha
     }
 
     /* Store the user_id */
-    user_id = db_handle->resultset->data[0][0].v_long;
+    user_id = db_handle->resultset->data[0][0].v.v_long;
 
     /* Done, need to clean up */
 fail_jobrep:
@@ -201,7 +214,7 @@ jobrep_push_unix_gid_voms_fqans(struct jr_db_handle_s *db_handle) {
             lcmaps_log(LOG_ERR, "%s: Unable to Prepare the query to insert into the voms_fqans\n", __func__);
             goto fail_jobrep;
         }
-        if (SQL_BindParam(db_handle, 1, SQL_C_CHAR, SQL_VARCHAR, vo_mapping[i].vostring) < 0) {
+        if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_CHAR, SQL_VARCHAR, vo_mapping[i].vostring) < 0) {
             lcmaps_log(LOG_ERR, "%s: Unable to bind the Subject DN value to the query\n", __func__);
             goto fail_jobrep;
         }
@@ -230,7 +243,7 @@ jobrep_get_voms_fqan_id_from_fqan(struct jr_db_handle_s *db_handle, char *voms_f
         lcmaps_log(LOG_ERR, "%s: Failed to prepare a query to select the voms_fqan_id from the voms_fqans\n", __func__);
         goto fail_jobrep;
     }
-    if (SQL_BindParam(db_handle, 1, SQL_C_CHAR, SQL_VARCHAR, voms_fqan) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_CHAR, SQL_VARCHAR, voms_fqan) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the VOMS FQAN value to the query\n", __func__);
         goto fail_jobrep;
     }
@@ -258,7 +271,7 @@ jobrep_get_voms_fqan_id_from_fqan(struct jr_db_handle_s *db_handle, char *voms_f
     }
 
     /* Store the voms_fqan_id */
-    voms_fqan_id = db_handle->resultset->data[0][0].v_long;
+    voms_fqan_id = db_handle->resultset->data[0][0].v.v_long;
 
 fail_jobrep:
     /* Clean up */
@@ -321,7 +334,7 @@ jobrep_get_unix_uid_id_from_uid(struct jr_db_handle_s *db_handle, uid_t uid, cha
     }
 
     /* Store the voms_fqan_id */
-    unix_uid_id = db_handle->resultset->data[0][0].v_long;
+    unix_uid_id = db_handle->resultset->data[0][0].v.v_long;
 
 fail_jobrep:
     /* Clean up */
@@ -334,6 +347,10 @@ long
 jobrep_get_unix_gid_id_from_gid(struct jr_db_handle_s *db_handle, gid_t gid, char *gid_name) {
     long unix_gid_id = -1;
     SQLRETURN ret;
+    char emptyname[5];
+
+    strncpy(emptyname,"NULL",5);
+
 
     if (db_handle == NULL) {
         return -1;
@@ -344,17 +361,17 @@ jobrep_get_unix_gid_id_from_gid(struct jr_db_handle_s *db_handle, gid_t gid, cha
         lcmaps_log(LOG_ERR, "%s: Failed to prepare a query to select the unix_gid_id from the unix_gids\n", __func__);
         goto fail_jobrep;
     }
-    if (SQL_BindParam(db_handle, 1, SQL_C_LONG, SQL_INTEGER, &gid) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_LONG, SQL_INTEGER, &gid) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the Unix GID value to the query\n", __func__);
         goto fail_jobrep;
     }
     if (gid_name == NULL) {
-        if (SQL_BindParam(db_handle, 2, SQL_C_CHAR, SQL_VARCHAR, "NULL") < 0) {
+        if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_CHAR, SQL_VARCHAR, emptyname) < 0) {
             lcmaps_log(LOG_ERR, "%s: Unable to bind the Unix GID value to the query\n", __func__);
             goto fail_jobrep;
         }
     } else {
-        if (SQL_BindParam(db_handle, 2, SQL_C_CHAR, SQL_VARCHAR, gid_name) < 0) {
+        if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_CHAR, SQL_VARCHAR, gid_name) < 0) {
             lcmaps_log(LOG_ERR, "%s: Unable to bind the Unix GID value to the query\n", __func__);
             goto fail_jobrep;
         }
@@ -383,7 +400,7 @@ jobrep_get_unix_gid_id_from_gid(struct jr_db_handle_s *db_handle, gid_t gid, cha
     }
 
     /* Store the voms_fqan_id */
-    unix_gid_id = db_handle->resultset->data[0][0].v_long;
+    unix_gid_id = db_handle->resultset->data[0][0].v.v_long;
 
 fail_jobrep:
     /* Clean up */
@@ -408,16 +425,16 @@ jobrep_insert_unix_uid_voms_fqans(struct jr_db_handle_s *db_handle, long voms_fq
         goto fail_jobrep;
     }
     reg_datetime = jobrep_time_to_string(time(NULL));
-    if (SQL_BindParam(db_handle, 1, SQL_C_CHAR, SQL_VARCHAR, reg_datetime) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_CHAR, SQL_VARCHAR, reg_datetime) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the Registration DateTime value to the query\n", __func__);
         goto fail_jobrep;
     }
 
-    if (SQL_BindParam(db_handle, 2, SQL_C_LONG, SQL_INTEGER, &unix_uid_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_LONG, SQL_INTEGER, &unix_uid_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the Unix GID ID value to the query\n", __func__);
         goto fail_jobrep;
     }
-    if (SQL_BindParam(db_handle, 3, SQL_C_LONG, SQL_INTEGER, &voms_fqan_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)3, SQL_C_LONG, SQL_INTEGER, &voms_fqan_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the VOMS FQAN ID value to the query\n", __func__);
         goto fail_jobrep;
     }
@@ -433,11 +450,11 @@ jobrep_insert_unix_uid_voms_fqans(struct jr_db_handle_s *db_handle, long voms_fq
         goto fail_jobrep;
     }
 
-    if (SQL_BindParam(db_handle, 1, SQL_C_LONG, SQL_INTEGER, &unix_uid_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_LONG, SQL_INTEGER, &unix_uid_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the Unix GID ID value to the query\n", __func__);
         goto fail_jobrep;
     }
-    if (SQL_BindParam(db_handle, 2, SQL_C_LONG, SQL_INTEGER, &voms_fqan_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_LONG, SQL_INTEGER, &voms_fqan_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the VOMS FQAN ID value to the query\n", __func__);
         goto fail_jobrep;
     }
@@ -460,7 +477,7 @@ jobrep_insert_unix_uid_voms_fqans(struct jr_db_handle_s *db_handle, long voms_fq
     }
 
     /* Store the cert_id */
-    unix_uid_voms_fqan_id = db_handle->resultset->data[0][0].v_long;
+    unix_uid_voms_fqan_id = db_handle->resultset->data[0][0].v.v_long;
 
     /* Clean up */
     SQL_QueryCloseAndClean(db_handle);
@@ -490,20 +507,20 @@ jobrep_insert_unix_gid_voms_fqans(struct jr_db_handle_s *db_handle, long voms_fq
         goto fail_jobrep;
     }
     reg_datetime = jobrep_time_to_string(time(NULL));
-    if (SQL_BindParam(db_handle, 1, SQL_C_CHAR, SQL_VARCHAR, reg_datetime) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_CHAR, SQL_VARCHAR, reg_datetime) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the Registration DateTime value to the query\n", __func__);
         goto fail_jobrep;
     }
 
-    if (SQL_BindParam(db_handle, 2, SQL_C_LONG, SQL_INTEGER, &unix_gid_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_LONG, SQL_INTEGER, &unix_gid_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the Unix GID ID value to the query\n", __func__);
         goto fail_jobrep;
     }
-    if (SQL_BindParam(db_handle, 3, SQL_C_LONG, SQL_INTEGER, &voms_fqan_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)3, SQL_C_LONG, SQL_INTEGER, &voms_fqan_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the VOMS FQAN ID value to the query\n", __func__);
         goto fail_jobrep;
     }
-    if (SQL_BindParam(db_handle, 4, SQL_C_LONG, SQL_INTEGER, &is_primary) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)4, SQL_C_LONG, SQL_INTEGER, &is_primary) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the Registration DateTime value to the query\n", __func__);
         goto fail_jobrep;
     }
@@ -519,15 +536,15 @@ jobrep_insert_unix_gid_voms_fqans(struct jr_db_handle_s *db_handle, long voms_fq
         goto fail_jobrep;
     }
 
-    if (SQL_BindParam(db_handle, 1, SQL_C_LONG, SQL_INTEGER, &unix_gid_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_LONG, SQL_INTEGER, &unix_gid_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the Unix GID ID value to the query\n", __func__);
         goto fail_jobrep;
     }
-    if (SQL_BindParam(db_handle, 2, SQL_C_LONG, SQL_INTEGER, &voms_fqan_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_LONG, SQL_INTEGER, &voms_fqan_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the VOMS FQAN ID value to the query\n", __func__);
         goto fail_jobrep;
     }
-    if (SQL_BindParam(db_handle, 3, SQL_C_LONG, SQL_INTEGER, &is_primary) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)3, SQL_C_LONG, SQL_INTEGER, &is_primary) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the Registration DateTime value to the query\n", __func__);
         goto fail_jobrep;
     }
@@ -550,7 +567,7 @@ jobrep_insert_unix_gid_voms_fqans(struct jr_db_handle_s *db_handle, long voms_fq
     }
 
     /* Store the cert_id */
-    unix_gid_voms_fqan_id = db_handle->resultset->data[0][0].v_long;
+    unix_gid_voms_fqan_id = db_handle->resultset->data[0][0].v.v_long;
 
     /* Clean up */
     SQL_QueryCloseAndClean(db_handle);
@@ -577,7 +594,7 @@ jobrep_create_effective_credentials_main(struct jr_db_handle_s *db_handle) {
 
     /* Bind data to Query */
     reg_datetime = jobrep_time_to_string(time(NULL));
-    if (SQL_BindParam(db_handle, 1, SQL_C_CHAR, SQL_VARCHAR, reg_datetime) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_CHAR, SQL_VARCHAR, reg_datetime) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the Registration DateTime value to the query\n", __func__);
         goto fail_jobrep;
     }
@@ -616,7 +633,7 @@ jobrep_create_effective_credentials_main(struct jr_db_handle_s *db_handle) {
     }
 
     /* Store the cert_id */
-    eff_cred_id = db_handle->resultset->data[0][0].v_long;
+    eff_cred_id = db_handle->resultset->data[0][0].v.v_long;
 
 fail_jobrep:
     /* Clean up */
@@ -638,11 +655,11 @@ jobrep_push_compute_job_info(struct jr_db_handle_s *db_handle, long eff_cred_id,
     }
 
     /* Bind data to Query */
-    if (SQL_BindParam(db_handle, 1, SQL_C_LONG, SQL_INTEGER, &eff_cred_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_LONG, SQL_INTEGER, &eff_cred_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the \"eff_cred_id\" value to the query\n", __func__);
         goto fail_jobrep;
     }
-    if (SQL_BindParam(db_handle, 2, SQL_C_CHAR, SQL_VARCHAR, gatekeeper_jm_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_CHAR, SQL_VARCHAR, gatekeeper_jm_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the \"GATEKEEPER_JM_ID\" value to the query\n", __func__);
         goto fail_jobrep;
     }
@@ -683,7 +700,7 @@ jobrep_push_voms_fqans(struct jr_db_handle_s *db_handle, long eff_cred_id) {
             lcmaps_log(LOG_ERR, "%s: Unable to Prepare the query to insert into the voms_fqans\n", __func__);
             goto fail_jobrep;
         }
-        if (SQL_BindParam(db_handle, 1, SQL_C_CHAR, SQL_VARCHAR, vo_mapping[i].vostring) < 0) {
+        if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_CHAR, SQL_VARCHAR, vo_mapping[i].vostring) < 0) {
             lcmaps_log(LOG_ERR, "%s: Unable to bind the Subject DN value to the query\n", __func__);
             goto fail_jobrep;
         }
@@ -728,11 +745,11 @@ jobrep_push_voms_fqans(struct jr_db_handle_s *db_handle, long eff_cred_id) {
         }
 
         /* Bind data to Query */
-        if (SQL_BindParam(db_handle, 1, SQL_C_LONG, SQL_INTEGER, &eff_cred_id) < 0) {
+        if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_LONG, SQL_INTEGER, &eff_cred_id) < 0) {
             lcmaps_log(LOG_ERR, "%s: Unable to bind the \"eff_cred_id\" value to the query\n", __func__);
             goto fail_jobrep;
         }
-        if (SQL_BindParam(db_handle, 2, SQL_C_LONG, SQL_INTEGER, &unix_gid_voms_fqan_id) < 0) {
+        if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_LONG, SQL_INTEGER, &unix_gid_voms_fqan_id) < 0) {
             lcmaps_log(LOG_ERR, "%s: Unable to bind the \"unix_gid_voms_fqan_id\" value to the query\n", __func__);
             goto fail_jobrep;
         }
@@ -764,11 +781,11 @@ jobrep_push_effective_credential_user(struct jr_db_handle_s *db_handle, long use
     }
 
     /* Bind data to Query */
-    if (SQL_BindParam(db_handle, 1, SQL_C_LONG, SQL_INTEGER, &eff_cred_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_LONG, SQL_INTEGER, &eff_cred_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the \"eff_cred_id\" value to the query\n", __func__);
         goto fail_jobrep;
     }
-    if (SQL_BindParam(db_handle, 2, SQL_C_LONG, SQL_INTEGER, &user_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_LONG, SQL_INTEGER, &user_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the \"user_id\" value to the query\n", __func__);
         goto fail_jobrep;
     }
@@ -822,11 +839,11 @@ jobrep_push_effective_credential_unix_uid(struct jr_db_handle_s *db_handle, long
         }
 
         /* Bind data to Query */
-        if (SQL_BindParam(db_handle, 1, SQL_C_LONG, SQL_INTEGER, &eff_cred_id) < 0) {
+        if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_LONG, SQL_INTEGER, &eff_cred_id) < 0) {
             lcmaps_log(LOG_ERR, "%s: Unable to bind the \"eff_cred_id\" value to the query\n", __func__);
             goto fail_jobrep;
         }
-        if (SQL_BindParam(db_handle, 2, SQL_C_LONG, SQL_INTEGER, &unix_uid_voms_fqan_id) < 0) {
+        if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_LONG, SQL_INTEGER, &unix_uid_voms_fqan_id) < 0) {
             lcmaps_log(LOG_ERR, "%s: Unable to bind the \"unix_uid_voms_fqan_id\" value to the query\n", __func__);
             goto fail_jobrep;
         }
@@ -848,11 +865,11 @@ jobrep_push_effective_credential_unix_uid(struct jr_db_handle_s *db_handle, long
     }
 
     /* Bind data to Query */
-    if (SQL_BindParam(db_handle, 1, SQL_C_LONG, SQL_INTEGER, &eff_cred_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_LONG, SQL_INTEGER, &eff_cred_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the \"eff_cred_id\" value to the query\n", __func__);
         goto fail_jobrep;
     }
-    if (SQL_BindParam(db_handle, 2, SQL_C_LONG, SQL_INTEGER, &unix_uid_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_LONG, SQL_INTEGER, &unix_uid_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the \"unix_uid_id\" value to the query\n", __func__);
         goto fail_jobrep;
     }
@@ -884,15 +901,15 @@ jobrep_push_effective_credential_unix_gid(struct jr_db_handle_s *db_handle, long
     }
 
     /* Bind data to Query */
-    if (SQL_BindParam(db_handle, 1, SQL_C_LONG, SQL_INTEGER, &eff_cred_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_LONG, SQL_INTEGER, &eff_cred_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the \"eff_cred_id\" value to the query\n", __func__);
         goto fail_jobrep;
     }
-    if (SQL_BindParam(db_handle, 2, SQL_C_LONG, SQL_INTEGER, &unix_gid_id) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_LONG, SQL_INTEGER, &unix_gid_id) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the \"unix_gid_id\" value to the query\n", __func__);
         goto fail_jobrep;
     }
-    if (SQL_BindParam(db_handle, 3, SQL_C_LONG, SQL_INTEGER, &is_primary) < 0) {
+    if (SQL_BindParam(db_handle, (SQLUSMALLINT)3, SQL_C_LONG, SQL_INTEGER, &is_primary) < 0) {
         lcmaps_log(LOG_ERR, "%s: Unable to bind the \"is_primary\" value to the query\n", __func__);
         goto fail_jobrep;
     }
@@ -936,10 +953,10 @@ jobrep_push_effective_credential_unix_gids(struct jr_db_handle_s *db_handle, lon
         }
 
         if (jobrep_push_effective_credential_unix_gid(db_handle, unix_gid_id, eff_cred_id, 1) < 0) {
-            lcmaps_log(LOG_ERR, "%s: Failed to push the effective_credential_unix_gid record based on the unix_gid_id %d and eff_cred_id %d\n",
+            lcmaps_log(LOG_ERR, "%s: Failed to push the effective_credential_unix_gid record based on the unix_gid_id %ld and eff_cred_id %ld\n",
                                 __func__,
-                                unix_gid_id,
-                                eff_cred_id);
+                                (long)unix_gid_id,
+                                (long)eff_cred_id);
             goto fail_jobrep;
         }
     }
@@ -958,10 +975,10 @@ jobrep_push_effective_credential_unix_gids(struct jr_db_handle_s *db_handle, lon
         }
 
         if (jobrep_push_effective_credential_unix_gid(db_handle, unix_gid_id, eff_cred_id, 0) < 0) {
-            lcmaps_log(LOG_ERR, "%s: Failed to push the effective_credential_unix_gid record based on the unix_gid_id %d and eff_cred_id %d\n",
+            lcmaps_log(LOG_ERR, "%s: Failed to push the effective_credential_unix_gid record based on the unix_gid_id %ld and eff_cred_id %ld\n",
                                 __func__,
-                                unix_gid_id,
-                                eff_cred_id);
+                                (long)unix_gid_id,
+                                (long)eff_cred_id);
             goto fail_jobrep;
         }
     }
@@ -983,9 +1000,12 @@ jobrep_push_unix_cred(struct jr_db_handle_s *db_handle) {
     int                    cntSecGid = 0;
     struct passwd         *user_info = NULL;
     struct group          *group_info = NULL;
+    char                  emptyname[5];
+
+    strncpy(emptyname,"NULL",5);
 
     if (db_handle == NULL) {
-        lcmaps_log(LOG_ERR, "%s called with an empty Database handle\n");
+        lcmaps_log(LOG_ERR, "%s called with an empty Database handle\n", __func__);
         return -1;
     }
 
@@ -995,18 +1015,18 @@ jobrep_push_unix_cred(struct jr_db_handle_s *db_handle) {
         SQL_Prepare(db_handle, (unsigned char *)"insert into unix_uids (uid, uid_name) values(?, ?)");
 
         /* Bind data to Query */
-        if (SQL_BindParam(db_handle, 1, SQL_C_LONG, SQL_INTEGER, &(uid[0])) < 0) {
+        if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_LONG, SQL_INTEGER, &(uid[0])) < 0) {
             lcmaps_log(LOG_ERR, "%s: Unable to bind the UID value to the query\n", __func__);
             goto fail_jobrep;
         }
         user_info = getpwuid(uid[0]);
         if (user_info) {
-            if (SQL_BindParam(db_handle, 2, SQL_C_CHAR, SQL_VARCHAR, user_info->pw_name) < 0) {
+            if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_CHAR, SQL_VARCHAR, user_info->pw_name) < 0) {
                 lcmaps_log(LOG_ERR, "%s: Unable to bind the Username value to the query\n", __func__);
                 goto fail_jobrep;
             }
         } else {
-            if (SQL_BindParam(db_handle, 2, SQL_C_CHAR, SQL_VARCHAR, "NULL") < 0) {
+            if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_CHAR, SQL_VARCHAR, emptyname) < 0) {
                 lcmaps_log(LOG_ERR, "%s: Unable to bind the Username value to the query\n", __func__);
                 goto fail_jobrep;
             }
@@ -1023,18 +1043,18 @@ jobrep_push_unix_cred(struct jr_db_handle_s *db_handle) {
                     (unsigned char *)"select unix_uid_id from unix_uids where uid = ? and uid_name = ?");
 
         /* Bind data to Query */
-        if (SQL_BindParam(db_handle, 1, SQL_C_LONG, SQL_INTEGER, &(uid[0])) < 0) {
+        if (SQL_BindParam(db_handle,(SQLUSMALLINT) 1, SQL_C_LONG, SQL_INTEGER, &(uid[0])) < 0) {
             lcmaps_log(LOG_ERR, "%s: Unable to bind the UID value to the query\n", __func__);
             goto fail_jobrep;
         }
         /* user_info = getpwuid(uid[0]); - already got this */
         if (user_info) {
-            if (SQL_BindParam(db_handle, 2, SQL_C_CHAR, SQL_VARCHAR, user_info->pw_name) < 0) {
+            if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_CHAR, SQL_VARCHAR, user_info->pw_name) < 0) {
                 lcmaps_log(LOG_ERR, "%s: Unable to bind the Username value to the query\n", __func__);
                 goto fail_jobrep;
             }
         } else {
-            if (SQL_BindParam(db_handle, 2, SQL_C_CHAR, SQL_VARCHAR, "NULL") < 0) {
+            if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_CHAR, SQL_VARCHAR, emptyname) < 0) {
                 lcmaps_log(LOG_ERR, "%s: Unable to bind the Username value to the query\n", __func__);
                 goto fail_jobrep;
             }
@@ -1061,7 +1081,7 @@ jobrep_push_unix_cred(struct jr_db_handle_s *db_handle) {
         }
 
         /* Store the cert_id */
-        unix_uid_id_and_res = db_handle->resultset->data[0][0].v_long;
+        unix_uid_id_and_res = db_handle->resultset->data[0][0].v.v_long;
 
     } else {
         /* Non-result */
@@ -1074,18 +1094,18 @@ jobrep_push_unix_cred(struct jr_db_handle_s *db_handle) {
         SQL_Prepare(db_handle, (unsigned char *)"insert into unix_gids (gid, gid_name) values(?, ?)");
 
         /* Bind data to Query */
-        if (SQL_BindParam(db_handle, 1, SQL_C_LONG, SQL_INTEGER, &(priGid[0])) < 0) {
+        if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_LONG, SQL_INTEGER, &(priGid[0])) < 0) {
             lcmaps_log(LOG_ERR, "%s: Unable to bind the PriGID value to the query\n", __func__);
             goto fail_jobrep;
         }
         group_info = getgrgid(priGid[0]);
         if (group_info) {
-            if (SQL_BindParam(db_handle, 2, SQL_C_CHAR, SQL_VARCHAR, group_info->gr_name) < 0) {
+            if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_CHAR, SQL_VARCHAR, group_info->gr_name) < 0) {
                 lcmaps_log(LOG_ERR, "%s: Unable to bind the primary groupname value to the query\n", __func__);
                 goto fail_jobrep;
             }
         } else {
-            if (SQL_BindParam(db_handle, 2, SQL_C_CHAR, SQL_VARCHAR, "NULL") < 0) {
+            if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_CHAR, SQL_VARCHAR, emptyname) < 0) {
                 lcmaps_log(LOG_ERR, "%s: Unable to bind the primary groupname value to the query\n", __func__);
                 goto fail_jobrep;
             }
@@ -1101,18 +1121,18 @@ jobrep_push_unix_cred(struct jr_db_handle_s *db_handle) {
         SQL_Prepare(db_handle, (unsigned char *)"insert into unix_gids (gid, gid_name) values(?, ?)");
 
         /* Bind data to Query */
-        if (SQL_BindParam(db_handle, 1, SQL_C_LONG, SQL_INTEGER, &(secGid[i])) < 0) {
+        if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_LONG, SQL_INTEGER, &(secGid[i])) < 0) {
             lcmaps_log(LOG_ERR, "%s: Unable to bind the PriGID value to the query\n", __func__);
             goto fail_jobrep;
         }
         group_info = getgrgid(secGid[i]);
         if (group_info) {
-            if (SQL_BindParam(db_handle, 2, SQL_C_CHAR, SQL_VARCHAR, group_info->gr_name) < 0) {
+            if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_CHAR, SQL_VARCHAR, group_info->gr_name) < 0) {
                 lcmaps_log(LOG_ERR, "%s: Unable to bind the primary groupname value to the query\n", __func__);
                 goto fail_jobrep;
             }
         } else {
-            if (SQL_BindParam(db_handle, 2, SQL_C_CHAR, SQL_VARCHAR, "NULL") < 0) {
+            if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_CHAR, SQL_VARCHAR, emptyname) < 0) {
                 lcmaps_log(LOG_ERR, "%s: Unable to bind the primary groupname value to the query\n", __func__);
                 goto fail_jobrep;
             }
@@ -1164,7 +1184,7 @@ jobrep_push_certificates(struct jr_db_handle_s *db_handle, STACK_OF(X509) *px509
             /* Gain the purpose, CA or not */
             purpose = jobrep_grid_x509IsCA(cert);
 
-            not_before = jobrep_asn1TimeToTimeT(ASN1_STRING_data(X509_get_notBefore(cert)),0);
+            not_before = jobrep_asn1TimeToTimeT(ASN1_STRING_data(X509_get_notBefore(cert)),(size_t)0);
             not_before_str = jobrep_time_to_string(not_before);
             if (not_before_str == NULL) {
                 lcmaps_log(LOG_INFO, "%s: Conversion from a ASN1_TIME to a string failed for the Not Before time\n",
@@ -1172,7 +1192,7 @@ jobrep_push_certificates(struct jr_db_handle_s *db_handle, STACK_OF(X509) *px509
                 goto fail_jobrep;
             }
 
-            not_after  = jobrep_asn1TimeToTimeT(ASN1_STRING_data(X509_get_notAfter(cert)),0);
+            not_after  = jobrep_asn1TimeToTimeT(ASN1_STRING_data(X509_get_notAfter(cert)),(size_t)0);
             not_after_str = jobrep_time_to_string(not_after);
             if (not_after_str == NULL) {
                 lcmaps_log(LOG_INFO, "%s: Conversion from a ASN1_TIME to a string failed for the Not After time\n",
@@ -1185,27 +1205,27 @@ jobrep_push_certificates(struct jr_db_handle_s *db_handle, STACK_OF(X509) *px509
                                  "certificates (subject, issuer, purpose, serialnr, valid_from, valid_until) " \
                                  "      values (?,       ?,      ?,       ?,        ?,          ?)");
 
-            if (SQL_BindParam(db_handle, 1, SQL_C_CHAR, SQL_VARCHAR, subject_DN) < 0) {
+            if (SQL_BindParam(db_handle, (SQLUSMALLINT)1, SQL_C_CHAR, SQL_VARCHAR, subject_DN) < 0) {
                 lcmaps_log(LOG_ERR, "%s: Unable to bind the Subject DN value to the query\n", __func__);
                 goto fail_jobrep;
             }
-            if (SQL_BindParam(db_handle, 2, SQL_C_CHAR, SQL_VARCHAR, issuer_DN) < 0) {
+            if (SQL_BindParam(db_handle, (SQLUSMALLINT)2, SQL_C_CHAR, SQL_VARCHAR, issuer_DN) < 0) {
                 lcmaps_log(LOG_ERR, "%s: Unable to bind the Issuer DN value to the query\n", __func__);
                 goto fail_jobrep;
             }
-            if (SQL_BindParam(db_handle, 3, SQL_C_LONG, SQL_INTEGER, &purpose) < 0) {
+            if (SQL_BindParam(db_handle, (SQLUSMALLINT)3, SQL_C_LONG, SQL_INTEGER, &purpose) < 0) {
                 lcmaps_log(LOG_ERR, "%s: Unable to bind the Purpose value to the query\n", __func__);
                 goto fail_jobrep;
             }
-            if (SQL_BindParam(db_handle, 4, SQL_C_CHAR, SQL_VARCHAR, serialnr) < 0) {
+            if (SQL_BindParam(db_handle, (SQLUSMALLINT)4, SQL_C_CHAR, SQL_VARCHAR, serialnr) < 0) {
                 lcmaps_log(LOG_ERR, "%s: Unable to bind the Serial Nr value to the query\n", __func__);
                 goto fail_jobrep;
             }
-            if (SQL_BindParam(db_handle, 5, SQL_C_CHAR, SQL_VARCHAR, not_before_str) < 0) {
+            if (SQL_BindParam(db_handle, (SQLUSMALLINT)5, SQL_C_CHAR, SQL_VARCHAR, not_before_str) < 0) {
                 lcmaps_log(LOG_ERR, "%s: Unable to bind the Valid From value to the query\n", __func__);
                 goto fail_jobrep;
             }
-            if (SQL_BindParam(db_handle, 6, SQL_C_CHAR, SQL_VARCHAR, not_after_str) < 0) {
+            if (SQL_BindParam(db_handle, (SQLUSMALLINT)6, SQL_C_CHAR, SQL_VARCHAR, not_after_str) < 0) {
                 lcmaps_log(LOG_ERR, "%s: Unable to bind the Valid Until value to the query\n", __func__);
                 goto fail_jobrep;
             }
@@ -1269,7 +1289,8 @@ jobrep_get_serialnumber_as_string(X509 *cert) {
     /* Note: serialLen is int and >0 */
     temp = serialNumberDER = malloc((size_t)serialLen);
     if (serialNumberDER == NULL) {
-        lcmaps_log(LOG_DEBUG, "%s: Could not allocate %d bytes\n", serialLen);
+        lcmaps_log(LOG_DEBUG, "%s: Could not allocate %d bytes\n",
+		__func__, serialLen);
         return NULL;
     }
     /* Warning, the temp variable will be displaced, use the serialNumberDER instead. */
@@ -1279,7 +1300,8 @@ jobrep_get_serialnumber_as_string(X509 *cert) {
     len = (size_t)serialLen * 2 + 1;
     serialStr = malloc(len);
     if (serialStr == NULL) {
-        lcmaps_log(LOG_DEBUG, "%s: Could not allocate %d bytes\n", len);
+        lcmaps_log(LOG_DEBUG, "%s: Could not allocate %lu bytes\n",
+		__func__, (unsigned long)len);
         goto cleanup;
     }
 
@@ -1315,19 +1337,19 @@ jobrep_time_to_string(time_t some_time) {
     if (datetime == NULL)
         goto cleanup;
 
-    snprintf(datetime, 20, "%04d-%02d-%02d %02d:%02d:%02d",
+    snprintf(datetime, (size_t)20, "%04d-%02d-%02d %02d:%02d:%02d",
             tmpTime->tm_year + 1900, tmpTime->tm_mon + 1, tmpTime->tm_mday,
             tmpTime->tm_hour, tmpTime->tm_min, tmpTime->tm_sec);
 
     /* Done */
-    if (tmpTime) free(tmpTime);
+    free(tmpTime);
 
     return datetime;
 
     /* Failed */
 cleanup:
-    if (tmpTime) free(tmpTime);
-    if (datetime) free(datetime);
+    free(tmpTime);
+    free(datetime);
 
     return NULL;
 }
