@@ -11,25 +11,10 @@
 /*****************************************************************************
                             Include header files
 ******************************************************************************/
-#include "lcmaps_jobrep_config.h"
-#include <stdio.h>
-#include <stdlib.h>
-#include <ctype.h>
-#include <string.h>
-#include <pwd.h>
-
-#include <openssl/x509.h>
-#include <openssl/x509v3.h>
-#include <openssl/x509_vfy.h>
-#include <openssl/asn1.h>
-
-#include <lcmaps/lcmaps_modules.h>
-#include <lcmaps/lcmaps_arguments.h>
-#include <lcmaps/lcmaps_cred_data.h>
-#include <lcmaps/lcmaps_vo_data.h>
 
 #include "jobrep_odbc_api.h"
-
+#include <sys/types.h>
+#include <openssl/x509.h>
 
 /*****************************************************************************
                               Prototypes
