@@ -77,7 +77,7 @@ This means that you can mix these parameters as you like between the files. All
 
 
 
-
+#define _XOPEN_SOURCE	600
 
 /*****************************************************************************
                             Include header files
@@ -87,6 +87,7 @@ This means that you can mix these parameters as you like between the files. All
 #include <stdlib.h>
 #include <ctype.h>
 #include <string.h>
+#include <strings.h>
 
 #include <openssl/x509.h>
 
@@ -95,6 +96,12 @@ This means that you can mix these parameters as you like between the files. All
 #include <lcmaps/lcmaps_cred_data.h>
 #include <lcmaps/lcmaps_vo_data.h>
 
+#if defined(HAVE_LCMAPS_LCMAPS_PLUGIN_PROTOTYPES_H)
+#   include <lcmaps/lcmaps_plugin_prototypes.h>
+#else
+#   include "lcmaps_plugin_prototypes.h"
+#endif
+
 #include "jobrep_odbc_api.h"
 #include "jobrep_data_handling.h"
 
@@ -144,7 +151,7 @@ int plugin_initialize(
         char ** argv
 )
 {
-    char *logstr = PACKAGE_TARNAME "-" "plugin_initialize()";
+    const char *logstr = PACKAGE_TARNAME "-" "plugin_initialize()";
     int i;
 
     lcmaps_log_debug(5,"%s: passed arguments:\n", logstr);
@@ -229,7 +236,7 @@ int plugin_introspect(
         lcmaps_argument_t ** argv
 )
 {
-    char *logstr = PACKAGE_TARNAME "-" "plugin_introspect()";
+    const char *logstr = PACKAGE_TARNAME "-" "plugin_introspect()";
     static lcmaps_argument_t argList[] = {
         { "user_dn"     , "char *"           ,  1, NULL},
         {"px509_chain"  , "STACK_OF(X509) *" ,  0, NULL},
@@ -242,7 +249,7 @@ int plugin_introspect(
     *argv = argList;
     lcmaps_log_debug(5,"%s: before lcmaps_cntArgs()\n", logstr);
     *argc = lcmaps_cntArgs(argList);
-    lcmaps_log_debug(5,"%s: address first argument: 0x%x\n", logstr,argList);
+    lcmaps_log_debug(5,"%s: address first argument: %p\n", logstr,(void*)argList);
 
     lcmaps_log_debug(5,"%s: Introspect succeeded\n", logstr);
     return LCMAPS_MOD_SUCCESS;
@@ -299,7 +306,7 @@ static int plugin_run_or_verify(
         int lcmaps_mode
 )
 {
-    char                  *logstr = PACKAGE_TARNAME "-" "plugin_run()";
+    const char            *logstr = PACKAGE_TARNAME "-" "plugin_run()";
     struct jr_db_handle_s *db_handle = NULL;
     void                  *lcmaps_dummy_arg_val = NULL;
     STACK_OF(X509)        *px509_chain = NULL;
@@ -469,7 +476,7 @@ Returns:
 ******************************************************************************/
 int plugin_terminate(void)
 {
-    char *logstr = PACKAGE_TARNAME "-" "plugin_terminate()";
+    const char *logstr = PACKAGE_TARNAME "-" "plugin_terminate()";
     lcmaps_log_debug(1,"%s: terminating\n", logstr);
 
     if (jr_config_file) {
